class NotificationEvent:
    """Notification Events."""

    FAILED = 'failed'
    ACCEPTED = 'accepted'
    VALIDATED = 'validated'
    AUTHORIZED = 'authorized'
    DISPATCHED = 'dispatched'
    RECEIVED = 'received'
    CONSUMED = 'consumed'
