class CommandMethod:
    """Command methods."""

    GET = 'get'
    SET = 'set'
    DELETE = 'delete'
    MERGE = 'merge'
    OBSERVE = 'observe'
    SUBSCRIBE = 'subscribe'
    UNSUBSCRIBE = 'unsubscribe'
